/* ======================================================================
**  mframer.h -- This file is a part of CFramer (Frame preprocessor for C++)
**  Version 1.23
** ======================================================================
**
** ======================================================================
**  This source code may not be used for commercial reasons.
**  Please, notify us, if you make any changes to this file.
**
**  Copyright (c) by Max Schlee. All rights reserved.
**  MS LeRM Laboratory 2002-2003
**  www.geocities.com/mslerm
**  mslerm@gmx.de
** ======================================================================
*/

#ifndef __MFRAMER_H
#define __MFRAMER_H

#include "mstring.h"

#define frame(X) class X : public MFramer

// ----------------------------------------------------------------------
MString setFrameText(const MString& mstr)
{
    return mstr;
}


// =======================================================================
class MFramer {
private:
    static const char*   sm_pszID;
    static       int     sm_nCounter;
                 int     m_nObjectID;
                 MString m_mstrFrameText;

public:
    MFramer();
    virtual ~MFramer();

    const MFramer& exportToFile  (const char*        );
    const MFramer& exportToFile  (MString&           );
    const MFramer& importFromFile(const char*        );
    const MFramer& importFromFile(MString            );
    const MFramer& exportToStream(ostream&           );
          MString& setFrameText  (const MString& mstr);
          char*    getAddress    (                   );
          long     length        (                   ) const;

                operator MString (           ) const;
          char& operator[]       (const long&);
    const char& operator[]       (const long&) const;

    virtual MFramer& operator= (const MFramer&);

// Commonality to EasyWinBGI3 Mirtus-Project (www.geocities.com/mslerm/winbgi)
    virtual MString  getClassID  () const;
    virtual MString  getObjectID () const;
    virtual MString  getClassName() const;
};

// ----------------------------------------------------------------------
//  MFramer attributes and methods
// ----------------------------------------------------------------------
const char* MFramer::sm_pszID    = "97469bc1-a58f-4d3e-b3cb-c1b5eec1ad7c";
      int   MFramer::sm_nCounter = 0;

// ----------------------------------------------------------------------
MFramer::MFramer()
{
    m_nObjectID = sm_nCounter++;
}

// ----------------------------------------------------------------------
/*virtual*/MFramer::~MFramer()
{
    sm_nCounter--;
}

// ----------------------------------------------------------------------
/*virtual*/MFramer& MFramer::operator= (const MFramer& mfr)
{
    m_mstrFrameText = mfr.m_mstrFrameText;

    return *this;
}

// ----------------------------------------------------------------------
inline MFramer::operator MString () const
{
    return m_mstrFrameText;
}

// ----------------------------------------------------------------------
inline char& MFramer::operator[](const long& n)
{
    return m_mstrFrameText[n];
}

// ----------------------------------------------------------------------
inline const char& MFramer::operator[](const long& n) const
{
    return m_mstrFrameText[n];
}

// ----------------------------------------------------------------------
inline MString& MFramer::setFrameText(const MString& mstr)
{
    return m_mstrFrameText = mstr;    
}

// ----------------------------------------------------------------------
const MFramer& MFramer::exportToFile(const char* lpsz)
{
    m_mstrFrameText.exportToFile(lpsz);

    return *this;
}

// ----------------------------------------------------------------------
const MFramer& MFramer::exportToFile(MString& mstr)
{
    m_mstrFrameText.exportToFile(mstr);

    return *this;
}

// ----------------------------------------------------------------------
const MFramer& MFramer::importFromFile(const char* lpsz)
{
    m_mstrFrameText.importFromFile(lpsz);

    return *this;
}

// ----------------------------------------------------------------------
const MFramer& MFramer::importFromFile(MString mstr)
{
    m_mstrFrameText.importFromFile(mstr);

    return *this;
}

// ----------------------------------------------------------------------
const MFramer& MFramer::exportToStream(ostream& output)
{
    m_mstrFrameText.exportToStream(output);

    return *this;
}

// ----------------------------------------------------------------------
inline char* MFramer::getAddress() 
{
    return m_mstrFrameText.getAddress();
}

// ----------------------------------------------------------------------
inline long MFramer::length() const
{
    return m_mstrFrameText.length();
}

// ----------------------------------------------------------------------
/*virtual*/MString MFramer::getClassName() const
{
    return "MFramer";
}

// ----------------------------------------------------------------------
/*virtual*/MString MFramer::getClassID() const
{
    return sm_pszID;
}

// ----------------------------------------------------------------------
/*virtual*/MString MFramer::getObjectID() const
{
    return getClassID() + (MString)m_nObjectID;
}

#endif //__MFRAMER_H
